**Purpose**:
This document serves as a general guideline for my workstation deployment process when working with Fedora Workstation 41 and up.  This document will constantly evolve over time based on my needs.

## Automate Initial Configurations
```sh 
# Set Hostname
sudo hostnamectl set-hostname lab-desktop-01

# Setup Automatic Drive Mounting
echo "/dev/disk/by-uuid/B865-7BDB /mnt/500GB_WINDOWS_OS auto nosuid,nodev,nofail,x-gvfs-show 0 0
/dev/disk/by-uuid/C006EBA006EB95A6 /mnt/640GB_HDD_STORAGE auto nosuid,nodev,nofail,x-gvfs-show 0 0
/dev/disk/by-uuid/24C82CFEC82CCFBA /mnt/1TB_SSD_STORAGE auto nosuid,nodev,nofail,x-gvfs-show 0 0
/dev/disk/by-uuid/D64E9F534E9F2AEF /mnt/120GB_SSD_STORAGE auto nosuid,nodev,nofail,x-gvfs-show 0 0
/dev/disk/by-uuid/16D05248D0522E6D /mnt/2TB_SSD_STORAGE auto nosuid,nodev,nofail,x-gvfs-show 0 0" | sudo tee -a /etc/fstab

# Install Software
sudo yum update -y
sudo yum install -y steam firefox
sudo dnf install -y @xfce-desktop-environment

# Reboot Workstation
sudo reboot
```

!!! warning "Read-Only NTFS Disks (When Using Dual-Boot)"
    If you want to dual boot, you need to ensure that the Windows side does not have "Fast Boot" enabled.  You can locate the Fast Boot setting by locating the "Change what the power button does" settings, and unchecking the "Fast Boot" checkbox, then shutting down.

    The problem with Fast Boot is that it effectively leaves the shared disks between Windows and Linux in a locked read-only state, which makes installing Steam games and software impossible.

## Manually Address Remaining Things
At this point, we need to do some manual work, since not everything can be handled by the terminal.  

### Install Software (Software Manager)
Now we need to install a few things:

- NVIDIA Graphics Drivers Control Panel
- Discord Canary
- Betterbird
- Visual Studio Code
- Signal Desktop
- Solaar # (Logitech Unifying Software equivalant in Linux)

### Import XFCE Panel Configuration
At this point, we want to restore our custom taskbar / panels in XFCE, so the easiest way to do that is to import the configuration backup located in Nextcloud.

Backups are located here: https://cloud.bunny-lab.io/f/792649

### Configure Window Snapping
By default, XFCE has a really small threshold for telling windows to "snap" to the sides of the screens, such as a half:half arrangement.  This can be adjusted by navigating to "**Applications Menu > Settings > Settings Manager > Windows Manager Tweaks > Placement**"

Once you have reached this window, you will see a slider from "**Small**" to "**Large**".  Slide the slider all the way to the right, facing "**Large**".  Now windows will snap to the sides of the screen successfully.